@@ -10,7 +10,7 @@ from os.path import join as pjoin
 # returns a list of queries which correspond to a given query language and name
 def get_queries(query_language, name):
     d = os.path.dirname(os.path.realpath(__file__))
-    path_to_data_sets = pjoin(d, 'queries', query_language, 'name')
+    path_to_data_sets = pjoin(d, 'queries', query_language, name)
     queries = []
 
     for file in os.listdir(path_to_data_sets):
